%
%
% Example of ODE solver of MATLAB
%

% set initial condition for the problem
Y0 = [ -7.5 -3.6 30 ] ;

% Set a vector specifying the interval of integration, [t0,tf].
% The solver imposes the initial conditions at TSPAN(1),
% and integrates from TSPAN(1) to TSPAN(end). 
% To obtain solutions at specific times (all increasing or all decreasing), 
% use TSPAN = [t0,t1,...,tf].
TSPAN = [ 0:0.01:10 ] ;

% Runge-Kutta embedded of order 2 and 3 by Bogaci and Shampine
[T1,Y1] = ode23 ( @lorenz, TSPAN, Y0 ) ;

% Runge-Kutta embedded of order 4 and 5 by Dormand and Prince (first choice scheme)
[T2,Y2] = ode45 ( @lorenz, TSPAN, Y0 ) ;

% Adams-bashforth-Moulton PECE
[T3,Y3] = ode113 ( @lorenz, TSPAN, Y0 ) ;

% Numerical Differentiation Formula, similar to Backward Differetiation Formula
% by Gear. Useful for stiff problem.
[T4,Y4] = ode15s ( @lorenz, TSPAN, Y0 ) ;

% Rosenbrock of order 2. For stiff problem.
[T5,Y5] = ode23s ( @lorenz, TSPAN, Y0 ) ;

% Trapeziodal rule for moderately stiff problem
[T6,Y6] = ode23t ( @lorenz, TSPAN, Y0 ) ;

% TR-BDF2 an implit Runge-Kutta where the first stage is the 
% trapezoidal rule and teh second stage is a BDF formula of order 2
[T7,Y7] = ode23tb ( @lorenz, TSPAN, Y0 ) ;

%
% plot the functions approximated by various solver
%

plot( T1, Y1(:,1), 'r-',  ...
      T2, Y2(:,1), 'g--', ...
      T3, Y3(:,1), 'b:',  ...
      T4, Y4(:,1), 'c-.', ...
      T5, Y5(:,1), 'm-',  ...
      T6, Y6(:,1), 'y-',  ...
      T7, Y7(:,1), 'k-' )
